@@ -24,6 +24,7 @@
 #include "polkitqt1-authority.h"
 
 #include <QtDBus/QDBusInterface>
+#include <QtDBus/QDBusMessage>
 #include <QtDBus/QDBusReply>
 
 #include <polkit/polkit.h>
@@ -256,7 +257,7 @@ void Authority::Private::dbusSignalAdd(const QString &service, const QString &pa
 {
     // FIXME: This code seems to be nonfunctional - it needs to be fixed somewhere (is it Qt BUG?)
     QDBusConnection::systemBus().connect(service, path, interface, name,
-                                         q, SLOT(dbusFilter(const QDBusMessage &)));
+                                         q, SLOT(dbusFilter(QDBusMessage)));
 }
 
 void Authority::Private::dbusFilter(const QDBusMessage &message)
@@ -852,4 +853,4 @@ void Authority::revokeTemporaryAuthorizationCancel()
 
 }
 
-#include "polkitqt1-authority.moc"
+#include "moc_polkitqt1-authority.cpp"
